@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2001 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2002 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -40,11 +40,22 @@ struct mbtowc_funcs {
    * converts the byte sequence starting at s to a wide character. Up to n bytes
    * are available at s. n is >= 1.
    * Result is number of bytes consumed (if a wide character was read),
-   * or 0 if invalid, or -1 if n too small, or -1-(number of bytes consumed)
+   * or -1 if invalid, or -2 if n too small, or -2-(number of bytes consumed)
    * if only a shift sequence was read.
    */
+  int (*xxx_flushwc) (conv_t conv, ucs4_t *pwc);
+  /*
+   * int xxx_flushwc (conv_t conv, ucs4_t *pwc)
+   * returns to the initial state and stores the pending wide character, if any.
+   * Result is 1 (if a wide character was read) or 0 if none was pending.
+   */
 };
 
+/* Return code if invalid. (xxx_mbtowc) */
+#define RET_ILSEQ      -1
+/* Return code if only a shift sequence of n bytes was read. (xxx_mbtowc) */
+#define RET_TOOFEW(n)  (-2-(n))
+
 /*
  * Data type for conversion unicode -> multibyte
  */
@@ -54,23 +65,21 @@ struct wctomb_funcs {
    * int xxx_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
    * converts the wide character wc to the character set xxx, and stores the
    * result beginning at r. Up to n bytes may be written at r. n is >= 1.
-   * Result is number of bytes written, or 0 if invalid, or -1 if n too small.
+   * Result is number of bytes written, or -1 if invalid, or -2 if n too small.
    */
   int (*xxx_reset) (conv_t conv, unsigned char *r, int n);
   /*
    * int xxx_reset (conv_t conv, unsigned char *r, int n)
    * stores a shift sequences returning to the initial state beginning at r.
    * Up to n bytes may be written at r. n is >= 0.
-   * Result is number of bytes written, or -1 if n too small.
+   * Result is number of bytes written, or -2 if n too small.
    */
 };
 
-/* Return code if invalid. (xxx_mbtowc, xxx_wctomb) */
-#define RET_ILSEQ      0
-/* Return code if only a shift sequence of n bytes was read. (xxx_mbtowc) */
-#define RET_TOOFEW(n)  (-1-(n))
+/* Return code if invalid. (xxx_wctomb) */
+#define RET_ILUNI      -1
 /* Return code if output buffer is too small. (xxx_wctomb, xxx_reset) */
-#define RET_TOOSMALL   -1
+#define RET_TOOSMALL   -2
 
 /*
  * Contents of a conversion descriptor.
@@ -88,6 +97,7 @@ struct conv_struct {
   state_t ostate;
   /* Operation flags */
   int transliterate;
+  int discard_ilseq;
 };
 
 /*
@@ -245,5 +255,6 @@ typedef struct {
 #include "cp864.h"
 #include "cp865.h"
 #include "cp869.h"
+#include "cp1125.h"
 #endif
 
